==> kayenta-web-2.40.4-sources.jar: com/netflix/kayenta/controllers/CredentialsController.java <==
/*
 * Copyright 2017 Google, Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License")
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.netflix.kayenta.controllers;

import com.netflix.kayenta.security.AccountCredentials;
import com.netflix.kayenta.security.AccountCredentialsRepository;
import io.swagger.annotations.ApiOperation;
import java.util.Set;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

@RestController
@RequestMapping("/credentials")
public class CredentialsController {

  private final AccountCredentialsRepository accountCredentialsRepository;

  @Autowired
  public CredentialsController(AccountCredentialsRepository accountCredentialsRepository) {
    this.accountCredentialsRepository = accountCredentialsRepository;
  }

  @ApiOperation(value = "Retrieve a list of all configured credentials")
  @RequestMapping(method = RequestMethod.GET)
  Set<? extends AccountCredentials> list() {
    return accountCredentialsRepository.getAll();
  }

  @DeleteMapping("/{accountName}")
  public void deleteAccount(@PathVariable String accountName) {
    this.accountCredentialsRepository.deleteById(accountName);
  }
}

==> kayenta-web-2.42.1-sources.jar: com/netflix/kayenta/controllers/CredentialsController.java <==
/*
 * Copyright 2017 Google, Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License")
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.netflix.kayenta.controllers;

import com.netflix.kayenta.security.AccountCredentials;
import com.netflix.kayenta.security.AccountCredentialsRepository;
import io.swagger.v3.oas.annotations.Operation;
import java.util.Set;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

@RestController
@RequestMapping("/credentials")
public class CredentialsController {

  private final AccountCredentialsRepository accountCredentialsRepository;

  @Autowired
  public CredentialsController(AccountCredentialsRepository accountCredentialsRepository) {
    this.accountCredentialsRepository = accountCredentialsRepository;
  }

  @Operation(summary = "Retrieve a list of all configured credentials")
  @RequestMapping(method = RequestMethod.GET)
  Set<? extends AccountCredentials> list() {
    return accountCredentialsRepository.getAll();
  }

  @DeleteMapping("/{accountName}")
  public void deleteAccount(@PathVariable String accountName) {
    this.accountCredentialsRepository.deleteById(accountName);
  }
}
